const extend = require('deep-extend')
const columnWidth = 20

function preview (options) {
  const intro = '\ncreating release ' + options.tag_name +
    ' for ' + options.owner + '/' + options.repo + '\n'
  const prettyOptions = formatOptions(options)

  console.log(intro)

  prettyOptions.forEach(function (option) {
    console.log(option.column1 + option.column2)
  })

  console.log('')
}

function formatOptions (options) {
  const formatted = []
  const copy = extend({}, options)

  delete copy.auth
  delete copy.owner
  delete copy.repo
  delete copy.dryRun
  delete copy.yes
  delete copy.workpath

  const keys = Object.keys(copy).reverse()

  keys.forEach(function (key) {
    if (['assets', 'draft', 'prerelease'].indexOf(key) > -1) {
      if (!copy[key]) return
    }

    if (key === 'body') {
      const body = formatBody(copy.body)
      formatted.push.apply(formatted, body)
    } else {
      formatted.push({ column1: justify(key), column2: copy[key] })
    }
  })

  return formatted
}

function formatBody (body) {
  const arr = []
  arr.push({ column1: justify('body'), column2: '' })
  arr.push({ column1: '', column2: '' })
  body.split('\n').forEach(function (line) {
    arr.push({ column1: '', column2: line })
  })
  return arr
}

function justify (word) {
  let justified = word + ':'
  while (justified.length < columnWidth) justified += ' '
  return justified
}

module.exports = preview
